@@ -12,7 +12,7 @@ import importlib
 from itertools import chain
 from types import ModuleType
 from typing import TYPE_CHECKING, cast, Dict, Any, List, Iterator, \
-    Optional, Sequence, Union, Callable, MutableMapping, Set, Tuple
+    Optional, Sequence, Union, Callable, MutableMapping, Set
 
 from .exceptions import ElementPathTypeError, ElementPathValueError
 from .namespaces import XML_NAMESPACE
@@ -539,14 +539,20 @@ class XPathContext:
 
         :param axis: the context axis, default is 'following-sibling'.
         """
+        item: Union[TextNode, ElementProtocol]
+
         if isinstance(self.item, TypedElement):
             item = self.item.elem
+            parent = self.get_parent(item)
+        elif isinstance(self.item, TextNode):
+            item = self.item
+            parent = item.parent
         elif not is_etree_element(self.item) or callable(getattr(self.item, 'tag')):
             return
         else:
             item = cast(ElementNode, self.item)
+            parent = self.get_parent(item)
 
-        parent = self.get_parent(item)
         if parent is None:
             return
 
@@ -554,6 +560,15 @@ class XPathContext:
         self.axis = axis or 'following-sibling'
 
         if axis == 'preceding-sibling':
+            if is_element_node(parent):
+                elem = cast(ElementNode, parent)
+                if elem.text is not None:
+                    self.item = TextNode(elem.text, elem)
+                    if self.item == item:
+                        self.item, self.axis = status
+                        return
+                    yield self.item
+
             for child in parent:  # pragma: no cover
                 if child is item:
                     break
@@ -561,9 +576,16 @@ class XPathContext:
                 yield child
                 if child.tail is not None:
                     self.item = TextNode(child.tail, child, True)
+                    if self.item == item:
+                        break
                     yield self.item
         else:
             follows = False
+            if is_element_node(parent):
+                elem = cast(ElementNode, parent)
+                if elem.text is not None and item == TextNode(elem.text, elem):
+                    follows = True
+
             for child in parent:
                 if follows:
                     self.item = child
@@ -573,6 +595,11 @@ class XPathContext:
                         yield self.item
                 elif child is item:
                     follows = True
+                    if child.tail is not None:
+                        self.item = TextNode(child.tail, child, True)
+                        yield self.item
+                elif child.tail is not None and item == TextNode(child.tail, child, True):
+                    follows = True
 
         self.item, self.axis = status
 
@@ -586,7 +613,7 @@ class XPathContext:
         In this case set the context size at start and change both position and \
         item at each iteration. For default only context item is changed.
         """
-        descendants: Union[Iterator[Union[XPathNodeType, None]], Tuple[XPathNode]]
+        descendants: Any
         with_self = axis != 'descendant'
 
         if self.item is None:
